;**********************************************************************
;                                                                     *
;    Notes:RS232 serial signal is generated by the instructions, the 
;    internal oscillator has to be calibrated to the factory settings
;    OSCCAL, make sure your programmer is set to use the chip value
;    for OSCCAL.
;	 The ADC 10 bits are serially sent by 2 bytes.
;    Disable Case Sensitivity in Build Options for MPSAM.                                                           
;                                                                     *
;                                                                     *
;                                                                     *
;   This code is free to use, for more info   http://www.moty22.co.uk                                                                  *
;**********************************************************************

#include	<p12f675.inc>
;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_CPD_ON                      EQU     H'3EFF'
_CPD_OFF                     EQU     H'3FFF'
_CP_ON                       EQU     H'3F7F'
_CP_OFF                      EQU     H'3FFF'
_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FEF'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FF7'
_LP_OSC                      EQU     H'3FF8'
_XT_OSC                      EQU     H'3FF9'
_HS_OSC                      EQU     H'3FFA'
_EC_OSC                      EQU     H'3FFB'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_EXTRC_OSC_NOCLKOUT          EQU     H'3FFE'
_EXTRC_OSC_CLKOUT            EQU     H'3FFF'

        	__CONFIG   _CP_OFF & _CPD_OFF & _BODEN_OFF & _MCLRE_OFF & _WDT_OFF & _PWRTE_ON & _INTRC_OSC_NOCLKOUT 



;***** VARIABLE DEFINITIONS
TIMER1   EQU     0x20        ; variable 
bitcount EQU     0x22
ADC      EQU     0x23




;**********************************************************************
		ORG     0x000             ; processor reset vector
		goto    init              ; go to beginning of program
	
DELAY   MOVLW   D'66'         
        MOVWF   TIMER1
LOOP1   DECFSZ  TIMER1,F
        GOTO    LOOP1
        RETLW   0

; these first 4 instructions are required for the internal oscillator calibration.
init	call    0x3FF             ; retrieve factory calibration value
		bsf     STATUS,RP0        ; set file register bank to 1 
		movwf   OSCCAL            ; update register with factory cal value 
		bcf     STATUS,RP0        ; set file register bank to 0

		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		BSF	STATUS,RP0	;Switch to register bank 1

		MOVLW	B'00011111'
		MOVWF	TRISIO		;5 is output pin 2.

        movlw   B'01010100'  ;
        movwf   ANSEL       ;AN2 pin 5 anlogue inputs 
		BCF	    STATUS,RP0	;Switch Back to reg. Bank 0
		bsf     GPIO,5       ;set output high

		MOVLW	B'00010001'
		movwf	T1CON		;timer1 options, prescal=2
        movlw   B'00001001'
        movwf   ADCON0       ;AN2,adc off


main    bsf     ADCON0,GO_DONE    ;start convertion
        call    delay
        
        BSF	    STATUS,RP0	;Switch to register bank 1
        movf    ADRESL,0
        BCF	    STATUS,RP0	;Switch Back to reg. Bank 0
        movwf   ADC
        
        bcf     GPIO,5       ;start first byte from ADC bits 0-2
        call    delay
        btfss   ADC,6
        bcf     GPIO,5       ;if bit low then send 0
        btfsc   ADC,6
        bsf     GPIO,5       ;if bit high then send 1
        call    delay
        btfss   ADC,7
        bcf     GPIO,5       ;if bit low then send 0
        btfsc   ADC,7
        bsf     GPIO,5       ;if bit high then send 1
        call    delay
        
        btfss   ADRESH,0	;bit 0 of ADRESH
        bcf     GPIO,5       ;if bit low then send 0
        btfsc   ADRESH,0
        bsf     GPIO,5       ;if bit high then send 1
        call    delay
        
        bcf     GPIO,5
        call    delay		;5 bit of zero
        call    delay
        call    delay 
        call    delay
        call    delay
        bsf     GPIO,5     ;idle
        call    delay 
        call    delay
        call    delay
        
        movlw   .7
        movwf   bitcount
        bcf     GPIO,5       ;start second byte from ADC bits 3-9
        call    delay
bits    rrf     ADRESH,1
		btfss   ADRESH,0
        bcf     GPIO,5       ;if bit low then send 0
        btfsc   ADRESH,0
        bsf     GPIO,5       ;if bit high then send 1
        call    delay
        
        decfsz  bitcount,1
        goto    bits
   		bsf     GPIO,5		;bit 8 is 1 for coding the byte

  
timeup     btfss   PIR1,0	;take a break
        goto    timeup
        bcf     PIR1,0
        goto    main 

		END                       

